@@ -21,8 +21,8 @@
 # SOFTWARE.
 import logging
 
-from squeak.core.signing import SqueakPrivateKey
-from squeak.core.signing import SqueakPublicKey
+from squeak.core.keys import SqueakPrivateKey
+from squeak.core.keys import SqueakPublicKey
 
 from proto import squeak_admin_pb2
 from squeaknode.admin.messages import connected_peer_to_message
@@ -292,12 +292,21 @@ class SqueakAdminServerHandler(object):
         replyto_hash_str = request.replyto
         replyto_hash = bytes.fromhex(
             replyto_hash_str) if replyto_hash_str else None
-        logger.info("Handle make squeak profile with id: {}".format(profile_id))
+        has_recipient = request.has_recipient
+        recipient_profile_id = request.recipient_profile_id if has_recipient else None
+        logger.info(
+            "Handle make squeak with author profile id: {}, and recipient profile id: {}".format(
+                profile_id, recipient_profile_id)
+        )
         inserted_squeak_hash = self.squeak_controller.make_squeak(
-            profile_id, content_str, replyto_hash
+            profile_id,
+            content_str,
+            replyto_hash,
+            recipient_profile_id,
         )
         inserted_squeak_hash_str = optional_squeak_hash_to_hex(
-            inserted_squeak_hash)
+            inserted_squeak_hash,
+        )
         return squeak_admin_pb2.MakeSqueakReply(
             squeak_hash=inserted_squeak_hash_str,
         )
@@ -682,6 +691,27 @@ class SqueakAdminServerHandler(object):
             sent_payment_id=sent_payment_id,
         )
 
+    def handle_decrypt_squeak(self, request):
+        squeak_hash_str = request.squeak_hash
+        squeak_hash = bytes.fromhex(squeak_hash_str)
+        has_author = request.has_author
+        author_profile_id = request.author_profile_id if has_author else None
+        has_recipient = request.has_recipient
+        recipient_profile_id = request.recipient_profile_id if has_recipient else None
+        logger.info(
+            "Handle decrypt squeak with hash: {}, recipient id: {}, author id: {}".format(
+                squeak_hash_str,
+                recipient_profile_id,
+                author_profile_id,
+            ),
+        )
+        self.squeak_controller.decrypt_private_squeak(
+            squeak_hash=squeak_hash,
+            author_profile_id=author_profile_id,
+            recipient_profile_id=recipient_profile_id,
+        )
+        return squeak_admin_pb2.DecryptSqueakReply()
+
     def handle_get_sent_payments(self, request):
         limit = request.limit
         last_sent_payment = message_to_sent_payment(request.last_sent_payment) if request.HasField(
@@ -1071,31 +1101,19 @@ class SqueakAdminServerHandler(object):
             default_price_msat=default_sell_price_msat,
         )
 
-    def handle_set_twitter_bearer_token(self, request):
-        twitter_bearer_token = request.bearer_token
-        logger.info("Handle set twitter bearer token with value: {}".format(
-            twitter_bearer_token,
-        ))
-        self.squeak_controller.set_twitter_bearer_token(twitter_bearer_token)
-        return squeak_admin_pb2.SetTwitterBearerTokenReply()
-
-    def handle_get_twitter_bearer_token(self, request):
-        logger.info("Handle get twitter bearer token")
-        twitter_bearer_token = self.squeak_controller.get_twitter_bearer_token()
-        return squeak_admin_pb2.GetTwitterBearerTokenReply(
-            bearer_token=twitter_bearer_token,
-        )
-
     def handle_add_twitter_account(self, request):
         handle = request.handle
         profile_id = request.profile_id
-        logger.info("Handle add twitter account with handle: {} and profile_id: {}".format(
+        bearer_token = request.bearer_token
+        logger.info("Handle add twitter account with handle: {}, profile_id: {}, bearer token: {}".format(
             handle,
             profile_id,
+            bearer_token,
         ))
         twitter_account_id = self.squeak_controller.add_twitter_account(
             handle,
             profile_id,
+            bearer_token,
         )
         return squeak_admin_pb2.AddTwitterAccountReply(
             twitter_account_id=twitter_account_id,
@@ -1123,10 +1141,3 @@ class SqueakAdminServerHandler(object):
             twitter_account_id,
         )
         return squeak_admin_pb2.DeleteTwitterAccountReply()
-
-    def handle_get_twitter_stream_status(self, request):
-        logger.info("Handle get twitter stream status")
-        twitter_stream_status = self.squeak_controller.get_twitter_stream_status()
-        return squeak_admin_pb2.GetTwitterStreamStatusReply(
-            is_stream_active=twitter_stream_status,
-        )
